#[non_exhaustive]pub struct Reply {
pub parent_message_id: MsgId,
pub parent_message_body: String,
pub parent_user_id: UserId,
pub parent_user_name: DisplayName,
pub parent_user_login: UserName,
pub thread_message_id: MsgId,
pub thread_user_id: UserId,
pub thread_user_name: DisplayName,
pub thread_user_login: UserName,
}Available on crate feature
eventsub only.Expand description
Metadata for reply messages
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent_message_id: MsgIdAn ID that uniquely identifies the parent message that this message is replying to.
parent_message_body: StringThe message body of the parent message.
parent_user_id: UserIdUser ID of the sender of the parent message.
parent_user_name: DisplayNameUser name of the sender of the parent message.
parent_user_login: UserNameUser login of the sender of the parent message.
thread_message_id: MsgIdAn ID that identifies the parent message of the reply thread.
thread_user_id: UserIdUser ID of the sender of the thread’s parent message.
thread_user_name: DisplayNameUser name of the sender of the thread’s parent message.
thread_user_login: UserNameUser login of the sender of the thread’s parent message.